@@ -64,9 +64,8 @@ switch_main_context (GMainContext *cnx)
 {
   GList *list;
 
-#ifndef DISABLE_P2P
-  atspi_dbus_server_setup_with_g_main (spi_global_app_data->server, cnx);
-#endif
+  if (spi_global_app_data->server)
+    atspi_dbus_server_setup_with_g_main (spi_global_app_data->server, cnx);
   atspi_dbus_connection_setup_with_g_main (spi_global_app_data->bus, cnx);
   for (list = spi_global_app_data->direct_connections; list; list = list->next)
     atspi_dbus_connection_setup_with_g_main (list->data, cnx);
@@ -372,7 +371,11 @@ signal_is_needed (const gchar *klass, const gchar *major, const gchar *minor)
    * TODO: FOr 2.2, have at-spi2-core define a special "cache listener" for
    * this instead, so that we don't send these if no one is listening */
   if (!g_strcmp0 (data [1], "ChildrenChanged") ||
-      !g_strcmp0 (data [1], "PropertyChange") ||
+      ((!g_strcmp0 (data [1], "PropertyChange")) &&
+       (!g_strcmp0 (data [2], "accessible-name") ||
+        !g_strcmp0 (data [2], "accessible-description") ||
+        !g_strcmp0 (data [2], "accessible-parent") ||
+        !g_strcmp0 (data [2], "accessible-role"))) ||
       !g_strcmp0 (data [1], "StateChanged"))
   {
     g_free (data [2]);
@@ -1017,6 +1020,7 @@ children_changed_event_listener (GSignalInvocationHint * signal_hint,
                                             detail1);
       emit_event (accessible, ITF_EVENT_OBJECT, name, minor, detail1, detail2,
                   "(so)", ao, append_object);
+      g_object_unref (ao);
     }
   else
     {
